@@ -7,7 +7,7 @@ use utf8;
 
 BEGIN {
 	$MooX::Struct::AUTHORITY = 'cpan:TOBYINK';
-	$MooX::Struct::VERSION   = '0.012';
+	$MooX::Struct::VERSION   = '0.014';
 }
 
 use Moo          1.000000;
@@ -105,7 +105,7 @@ sub _data_printer
 	require Term::ANSIColor;
 	my $self   = shift;
 	
-	my @values = map { scalar &Data::Printer::p(\$_) } @$self;
+	my @values = map { scalar &Data::Printer::p(\$_, return_value => 'dump') } @$self;
 	my $label  = Term::ANSIColor::colored($self->TYPE||'struct', 'bright_yellow');
 
 	if (grep /\n/, @values)
@@ -126,7 +126,7 @@ BEGIN {
 	{
 		no warnings;
 		our $AUTHORITY = 'cpan:TOBYINK';
-		our $VERSION   = '0.012';
+		our $VERSION   = '0.014';
 	}
 	
 	sub _uniq { my %seen; grep { not $seen{$_}++ } @_ };
@@ -712,6 +712,8 @@ Automatic pretty printing with L<Data::Printer>.
  my $origin = Point[];
  p $origin;
 
+Use Data::Printer 0.36 or above please.
+
 =back
 
 With the exception of C<FIELDS> and C<TYPE>, any of these can be overridden
@@ -754,7 +756,7 @@ Toby Inkster E<lt>tobyink@cpan.orgE<gt>.
 
 =head1 COPYRIGHT AND LICENCE
 
-This software is copyright (c) 2012-2013 by Toby Inkster.
+This software is copyright (c) 2012-2013, 2017 by Toby Inkster.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
